==> SimplyAgree_0.2.1.tar.gz: SimplyAgree/R/globals.R <==
# Globals

utils::globalVariables(c("boot_bias",
                         "boot_within_sd",
                         "boot_between_sd",
                         "boot_total_sd",
                         "boot_low_loa",
                         "boot_upper_loa",
                         "vartab",
                         "Condition","X","d",
                         "both_avg", "x_bar", "y_bar",
                         "drop_na", "delta", "is.missing",
                         "CI.n", "power.power", "value",
                         "feature", "name", "stack",
                         "sf", "qf", "items", "values",
                         "avg_both", "stats.final",
                         "LOA.SD", "LOA.mu", "N", "agree.level",
                         "beta.delta", "conf.level", "power",
                         "y1", "upper.ci","lower.ci","estimate",
                         "conf.high", "conf.low", "lcl", "pred",
                         "predicted",
                         "the_int",
                         "the_slope",
                         "ucl", 'y',
                         "mean_y", "n_y",
                         "diff_y2", "n_x",
                         "diff_x", "mean_x",
                         "diff_y", "mean_y",
                         "at", "median", "confint",
                         "binomial", "glm",
                         "binom.test", "failure",
                         "success",
                         "diff_x2",
                         "level",
                         "Var1",
                         "Var2",
                         "Var3",
                         "avg",
                         "bias",
                         "boot_est",
                         "condition",
                         "high",
                         "low",
                         "nboot",
                         "sd_between",
                         "sd_within",
                         "se",
                         "SE",
                         "statistic",
                         "std.error",
                         "term",
                         "sd_total",
                         ".",
                         ":=",
                         "n_items",
                         "n_id",
                         "n_obs",
                         "se_type",
                         "type",
                         "x.df",
                         "agree_int", "alpha_u", "between_variance",
                         "call2", "conf2", "emmean", "grp",
                         "lmer_x", "lmer_y", "lower.CL", "lower_ci",
                         "lower_loa", "lower_loa_ci", "mxh_l", "myh_l",
                         "sd_delta", "tot_var", "upper.CL", "upper_ci",
                         "upper_loa", "upper_loa_ci", "var_loa", "x","1",
                         "Average of Both Methods",
                         "Bias",
                         "Bias CI",
                         "Prediction Interval",
                         "SEM", "SEP",
                         "Tolerance Limits", "replicates",
                         "upper.PL", "upper.TL",
                         "lower.PL", "lower.TL",
                         "asymp.LCL","asymp.UCL"))

==> SimplyAgree_0.3.0.tar.gz: SimplyAgree/R/globals.R <==
utils::globalVariables(c("boot_bias",
                         "boot_within_sd",
                         "boot_between_sd",
                         "boot_total_sd",
                         "boot_low_loa",
                         "boot_upper_loa",
                         "vartab",
                         "Condition","X","d",
                         "both_avg", "x_bar", "y_bar",
                         "drop_na", "delta", "is.missing",
                         "CI.n", "power.power", "value",
                         "feature", "name", "stack",
                         "sf", "qf", "items", "values",
                         "avg_both", "stats.final",
                         "LOA.SD", "LOA.mu", "N", "agree.level",
                         "beta.delta", "conf.level", "power",
                         "y1", "upper.ci","lower.ci","estimate",
                         "conf.high", "conf.low", "lcl", "pred",
                         "predicted",
                         "the_int",
                         "the_slope",
                         "ucl", 'y',
                         "mean_y", "n_y",
                         "diff_y2", "n_x",
                         "diff_x", "mean_x",
                         "diff_y", "mean_y",
                         "at", "median", "confint",
                         "binomial", "glm",
                         "binom.test", "failure",
                         "success",
                         "diff_x2",
                         "level",
                         "Var1",
                         "Var2",
                         "Var3",
                         "avg",
                         "bias",
                         "boot_est",
                         "condition",
                         "high",
                         "low",
                         "nboot",
                         "sd_between",
                         "sd_within",
                         "se",
                         "SE",
                         "statistic",
                         "std.error",
                         "term",
                         "sd_total",
                         ".",
                         ":=",
                         "n_items",
                         "n_id",
                         "n_obs",
                         "se_type",
                         "type",
                         "x.df",
                         "agree_int", "alpha_u", "between_variance",
                         "call2", "conf2", "emmean", "grp",
                         "lmer_x", "lmer_y", "lower.CL", "lower_ci",
                         "lower_loa", "lower_loa_ci", "mxh_l", "myh_l",
                         "sd_delta", "tot_var", "upper.CL", "upper_ci",
                         "upper_loa", "upper_loa_ci", "var_loa", "x","1",
                         "Average of Both Methods",
                         "Bias",
                         "Bias CI",
                         "Prediction Interval",
                         "SEM", "SEP",
                         "Tolerance Limits", "replicates",
                         "upper.PL", "upper.TL",
                         "lower.PL", "lower.TL",
                         "asymp.LCL","asymp.UCL",
                         "method", "slope", "intercept",
                         "xmin", "xmax", "ymin", "ymax",
                         "rbeta",
                         "id",
                         "index", "residual", "cusum", "lwr", "upr", "rank_x", "rank_y",
                         "the_int", "the_slope", "slope", "intercept", "xmin", "xmax",
                         "ymin", "ymax"))
